@@ -71,7 +71,7 @@ def bold_line(line: str) -> str:
     return f'\033[0;1m{line}\033[0m'
 
 
-def print_warning(message: str) -> None:
+def print_warning(message: str = '') -> None:
     print_stderr(' '.join([
         color_line(':: ' + _("warning:"), 11),
         message
